package Module::Install::Run;

use Module::Install::Base;
@ISA = qw(Module::Install::Base);

$VERSION = '0.01';

# eventually move the ipc::run / open3 stuff here.

1;
